@@ -47,7 +47,7 @@
 #endif
 
 #define ZOOM_BUTTONS  
-// #define DETAIL_POPUP
+#define DETAIL_POPUP
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
@@ -172,6 +172,7 @@ typedef struct appdata_s {
 #include "net_io.h"
 #include "banner.h"
 #include "list.h"
+#include "scale_popup.h"
 
 void main_ui_enable(appdata_t *appdata);
 
