@@ -448,13 +448,13 @@ static void osm_delete_nodes(osm_upload_context_t *context) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if(node->flags & OSM_FLAG_DELETED) {
+    if(OSM_FLAGS(node) & OSM_FLAG_DELETED) {
       printf("deleting node on server\n");
 
-      appendf(&context->log, NULL, _("Delete node #%ld "), node->id);
+      appendf(&context->log, NULL, _("Delete node #%ld "), OSM_ID(node));
 
       char *url = g_strdup_printf("%s/node/" ITEM_ID_FORMAT, 
-				  project->server, node->id);
+				  project->server, OSM_ID(node));
       char *cred = g_strdup_printf("%s:%s", 
 				   context->appdata->settings->username, 
 				   context->appdata->settings->password);
@@ -463,7 +463,7 @@ static void osm_delete_nodes(osm_upload_context_t *context) {
 	osm_generate_xml_node(context->osm, context->changeset, node);
 
       if(osm_delete_item(&context->log, xml_str, url, cred, context->proxy)) {
-	node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
+	OSM_FLAGS(node) &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->data_dirty = TRUE;
       }
       
@@ -481,17 +481,17 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if((node->flags & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) &&
-       (!(node->flags & OSM_FLAG_DELETED))) {
+    if((OSM_FLAGS(node) & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) &&
+       (!(OSM_FLAGS(node) & OSM_FLAG_DELETED))) {
       char *url = NULL;
 
-      if(node->flags & OSM_FLAG_NEW) {
+      if(OSM_FLAGS(node) & OSM_FLAG_NEW) {
 	url = g_strdup_printf("%s/node/create", project->server);
 	appendf(&context->log, NULL, _("New node "));
       } else {
 	url = g_strdup_printf("%s/node/" ITEM_ID_FORMAT, 
-			      project->server, node->id);
-	appendf(&context->log, NULL, _("Modified node #%ld "), node->id);
+			      project->server, OSM_ID(node));
+	appendf(&context->log, NULL, _("Modified node #%ld "), OSM_ID(node));
       }
 
       /* upload this node */
@@ -504,9 +504,9 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 				     context->appdata->settings->username, 
 				     context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-		   (node->flags & OSM_FLAG_NEW)?&(node->id):&(node->version),
+	   (OSM_FLAGS(node) & OSM_FLAG_NEW)?&(OSM_ID(node)):&OSM_VERSION(node),
 			   context->proxy)) {
-	  node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
+	  OSM_FLAGS(node) &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->data_dirty = TRUE;
 	}
 	g_free(cred);
@@ -525,13 +525,13 @@ static void osm_delete_ways(osm_upload_context_t *context) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if(way->flags & OSM_FLAG_DELETED) {
+    if(OSM_FLAGS(way) & OSM_FLAG_DELETED) {
       printf("deleting way on server\n");
 
-      appendf(&context->log, NULL, _("Delete way #%ld "), way->id);
+      appendf(&context->log, NULL, _("Delete way #%ld "), OSM_ID(way));
 
       char *url = g_strdup_printf("%s/way/" ITEM_ID_FORMAT, 
-				  project->server, way->id);
+				  project->server, OSM_ID(way));
       char *cred = g_strdup_printf("%s:%s", 
 				   context->appdata->settings->username, 
 				   context->appdata->settings->password);
@@ -540,7 +540,7 @@ static void osm_delete_ways(osm_upload_context_t *context) {
 	osm_generate_xml_way(context->osm, context->changeset, way);
 
       if(osm_delete_item(&context->log, xml_str, url, cred, context->proxy)) {
-	way->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
+	OSM_FLAGS(way) &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->data_dirty = TRUE;
       }
       
@@ -559,17 +559,17 @@ static void osm_upload_ways(osm_upload_context_t *context) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if((way->flags & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) &&
-       (!(way->flags & OSM_FLAG_DELETED))) {
+    if((OSM_FLAGS(way) & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) &&
+       (!(OSM_FLAGS(way) & OSM_FLAG_DELETED))) {
       char *url = NULL;
       
-      if(way->flags & OSM_FLAG_NEW) {
+      if(OSM_FLAGS(way) & OSM_FLAG_NEW) {
 	url = g_strdup_printf("%s/way/create", project->server);
 	appendf(&context->log, NULL, _("New way "));
       } else {
 	url = g_strdup_printf("%s/way/" ITEM_ID_FORMAT, 
-			      project->server, way->id);
-	appendf(&context->log, NULL, _("Modified way #%ld "), way->id);
+			      project->server, OSM_ID(way));
+	appendf(&context->log, NULL, _("Modified way #%ld "), OSM_ID(way));
       }
       
       /* upload this node */
@@ -582,9 +582,9 @@ static void osm_upload_ways(osm_upload_context_t *context) {
 				     context->appdata->settings->username, 
 				     context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-		   (way->flags & OSM_FLAG_NEW)?&(way->id):&(way->version),
+	   (OSM_FLAGS(way) & OSM_FLAG_NEW)?&(OSM_ID(way)):&OSM_VERSION(way),
 			   context->proxy)) {
-	  way->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
+	  OSM_FLAGS(way) &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->data_dirty = TRUE;
 	}
 	g_free(cred);
@@ -603,13 +603,14 @@ static void osm_delete_relations(osm_upload_context_t *context) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if(relation->flags & OSM_FLAG_DELETED) {
+    if(OSM_FLAGS(relation) & OSM_FLAG_DELETED) {
       printf("deleting relation on server\n");
 
-      appendf(&context->log, NULL, _("Delete relation #%ld "), relation->id);
+      appendf(&context->log, NULL, 
+	      _("Delete relation #%ld "), OSM_ID(relation));
 
       char *url = g_strdup_printf("%s/relation/" ITEM_ID_FORMAT, 
-				  project->server, relation->id);
+				  project->server, OSM_ID(relation));
       char *cred = g_strdup_printf("%s:%s", 
 				   context->appdata->settings->username, 
 				   context->appdata->settings->password);
@@ -618,7 +619,7 @@ static void osm_delete_relations(osm_upload_context_t *context) {
 	osm_generate_xml_relation(context->osm, context->changeset, relation);
 
       if(osm_delete_item(&context->log, xml_str, url, cred, context->proxy)) {
-	relation->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
+	OSM_FLAGS(relation) &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->data_dirty = TRUE;
       }
       
@@ -637,18 +638,18 @@ static void osm_upload_relations(osm_upload_context_t *context) {
     /* make sure gui gets updated */
     while(gtk_events_pending()) gtk_main_iteration();
 
-    if((relation->flags & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) &&
-       (!(relation->flags & OSM_FLAG_DELETED))) {
+    if((OSM_FLAGS(relation) & (OSM_FLAG_DIRTY | OSM_FLAG_NEW)) &&
+       (!(OSM_FLAGS(relation) & OSM_FLAG_DELETED))) {
       char *url = NULL;
       
-      if(relation->flags & OSM_FLAG_NEW) {
+      if(OSM_FLAGS(relation) & OSM_FLAG_NEW) {
 	url = g_strdup_printf("%s/relation/create", project->server);
 	appendf(&context->log, NULL, _("New relation "));
       } else {
 	url = g_strdup_printf("%s/relation/" ITEM_ID_FORMAT, 
-			      project->server,relation->id);
+			      project->server,OSM_ID(relation));
 	appendf(&context->log, NULL, _("Modified relation #%ld "), 
-		relation->id);
+		OSM_ID(relation));
       }
       
       /* upload this relation */
@@ -661,9 +662,9 @@ static void osm_upload_relations(osm_upload_context_t *context) {
 				     context->appdata->settings->username, 
 				     context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-	   (relation->flags & OSM_FLAG_NEW)?&(relation->id):&(relation->version),
-			   context->proxy)) {
-	  relation->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
+	   (OSM_FLAGS(relation) & OSM_FLAG_NEW)?&(OSM_ID(relation)):&
+			   OSM_VERSION(relation), context->proxy)) {
+	  OSM_FLAGS(relation) &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->data_dirty = TRUE;
 	}
 	g_free(cred);
@@ -774,9 +775,9 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   node_t *node = osm->node;
   while(node) {
     dirty.nodes.total++;
-    if(node->flags & OSM_FLAG_DELETED)     dirty.nodes.deleted++;
-    else if(node->flags & OSM_FLAG_NEW)    dirty.nodes.new++;
-    else if(node->flags & OSM_FLAG_DIRTY)  dirty.nodes.dirty++;
+    if(OSM_FLAGS(node) & OSM_FLAG_DELETED)     dirty.nodes.deleted++;
+    else if(OSM_FLAGS(node) & OSM_FLAG_NEW)    dirty.nodes.new++;
+    else if(OSM_FLAGS(node) & OSM_FLAG_DIRTY)  dirty.nodes.dirty++;
 
     node = node->next;
   }
@@ -787,9 +788,9 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   way_t *way = osm->way;
   while(way) {
     dirty.ways.total++;
-    if(way->flags & OSM_FLAG_DELETED)      dirty.ways.deleted++;
-    else if(way->flags & OSM_FLAG_NEW)     dirty.ways.new++;
-    else if(way->flags & OSM_FLAG_DIRTY)   dirty.ways.dirty++;
+    if(OSM_FLAGS(way) & OSM_FLAG_DELETED)      dirty.ways.deleted++;
+    else if(OSM_FLAGS(way) & OSM_FLAG_NEW)     dirty.ways.new++;
+    else if(OSM_FLAGS(way) & OSM_FLAG_DIRTY)   dirty.ways.dirty++;
 
     way = way->next;
   }
@@ -800,9 +801,9 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   relation_t *relation = osm->relation;
   while(relation) {
     dirty.relations.total++;
-    if(relation->flags & OSM_FLAG_DELETED)      dirty.relations.deleted++;
-    else if(relation->flags & OSM_FLAG_NEW)     dirty.relations.new++;
-    else if(relation->flags & OSM_FLAG_DIRTY)   dirty.relations.dirty++;
+    if(OSM_FLAGS(relation) & OSM_FLAG_DELETED)      dirty.relations.deleted++;
+    else if(OSM_FLAGS(relation) & OSM_FLAG_NEW)     dirty.relations.new++;
+    else if(OSM_FLAGS(relation) & OSM_FLAG_DIRTY)   dirty.relations.dirty++;
 
     relation = relation->next;
   }
